@@ -1,6 +1,6 @@
 """
- Use with:
- python3 setup.py build_exe --no-compress -O1
+Use with:
+python3 setup.py build_exe --no-compress -O1
 """
 
 import sys
@@ -88,6 +88,8 @@ PACKAGES = [
     "pydotplus",
     "pygraphviz",
     "pydot",
+    "orjson",
+    "selenium",
 ]
 EXCLUDES = [
     "tkinter",
