@@ -19,7 +19,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
-""" Unittest for testing dates """
+"""Unittest for testing dates"""
 
 # -------------------------------------------------------------------------
 #
@@ -34,11 +34,12 @@ import unittest
 #
 # -------------------------------------------------------------------------
 from ...config import config
-from ...datehandler import get_date_formats, set_format
-from ...datehandler import parser as _dp
 from ...datehandler import displayer as _dd
+from ...datehandler import get_date_formats
+from ...datehandler import parser as _dp
+from ...datehandler import set_format
 from ...datehandler._datedisplay import DateDisplayEn
-from ...lib.date import Date, DateError, Today, calendar_has_fixed_newyear, Span
+from ...lib.date import Date, DateError, Span, Today, calendar_has_fixed_newyear
 
 date_tests = {}
 
@@ -57,7 +58,13 @@ for quality in (Date.QUAL_NONE, Date.QUAL_ESTIMATED, Date.QUAL_CALCULATED):
     ):
         for month in range(1, 13):
             d = Date()
-            d.set(quality, modifier, calendar, (4, month, 1789, False), "Text comment")
+            d.set(
+                quality,
+                modifier,
+                calendar,
+                (4, month, 1789, False),
+                "Text comment",
+            )
             dates.append(d)
     for modifier in (Date.MOD_RANGE, Date.MOD_SPAN):
         for month1 in range(1, 13):
@@ -267,7 +274,13 @@ for calendar in (
             Date.MOD_TO,
         ):
             d = Date()
-            d.set(quality, modifier, calendar, (4, 11, 1789, False), "Text comment")
+            d.set(
+                quality,
+                modifier,
+                calendar,
+                (4, 11, 1789, False),
+                "Text comment",
+            )
             dates.append(d)
         for modifier in (Date.MOD_RANGE, Date.MOD_SPAN):
             d = Date()
@@ -304,7 +317,13 @@ with Context(Date.CAL_SWEDISH) as calendar:
             Date.MOD_TO,
         ):
             d = Date()
-            d.set(quality, modifier, calendar, (4, 11, 1700, False), "Text comment")
+            d.set(
+                quality,
+                modifier,
+                calendar,
+                (4, 11, 1700, False),
+                "Text comment",
+            )
             dates.append(d)
         for modifier in (Date.MOD_RANGE, Date.MOD_SPAN):
             d = Date()
@@ -343,7 +362,13 @@ with Context(Date.CAL_SWEDISH) as calendar:
     for year in range(1701, 1712):
         for month in range(1, 13):
             d = Date()
-            d.set(quality, modifier, calendar, (4, month, year, False), "Text comment")
+            d.set(
+                quality,
+                modifier,
+                calendar,
+                (4, month, year, False),
+                "Text comment",
+            )
             swedish_dates.append(d)
 
 
@@ -590,7 +615,9 @@ class ArithmeticDateTest(BaseDateTest):
             val1 = eval(exp1)
             val2 = eval(exp2)
             self.assertEqual(
-                val1, val2, "'%s' should be '%s' but was '%s'" % (exp1, val2, val1)
+                val1,
+                val2,
+                "'%s' should be '%s' but was '%s'" % (exp1, val2, val1),
             )
 
 
@@ -868,105 +895,600 @@ class DateComparisonTest(BaseDateTest):
         ("from 1960 to 1961", ">=", "from 1960 to 1961", True),
         ("from 1960 to 1961", ">=", "from 1961 to 1962", False),
         ("from 1960 to 1961", ">=", "from 1962 to 1963", False),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1958-01-01 to 1959-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1958-01-01 to 1960-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1958-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1958-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1960-01-01 to 1960-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1960-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1960-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1960-12-31 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1960-12-31 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1961-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "=", "from 1961-01-02 to 1961-01-03", False),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1958-01-01 to 1959-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1958-01-01 to 1960-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1958-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1958-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1960-01-01 to 1960-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1960-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1960-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1960-12-31 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1960-12-31 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1961-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "!=", "from 1961-01-02 to 1961-01-03", True),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1958-01-01 to 1959-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1958-01-01 to 1960-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1958-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1958-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1960-01-01 to 1960-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1960-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1960-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1960-12-31 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1960-12-31 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1961-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "==", "from 1961-01-02 to 1961-01-03", False),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1958-01-01 to 1959-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1958-01-01 to 1960-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1958-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1958-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1960-01-01 to 1960-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1960-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1960-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1960-12-31 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1960-12-31 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1961-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<", "from 1961-01-02 to 1961-01-03", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1958-01-01 to 1959-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1958-01-01 to 1960-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1958-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1958-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1960-01-01 to 1960-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1960-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1960-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1960-12-31 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1960-12-31 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1961-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">", "from 1961-01-02 to 1961-01-03", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1958-01-01 to 1959-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1958-01-01 to 1960-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1958-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1958-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1960-01-01 to 1960-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1960-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1960-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1960-12-31 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1960-12-31 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1961-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "<<", "from 1961-01-02 to 1961-01-03", True),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1958-01-01 to 1959-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1958-01-01 to 1960-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1958-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1958-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1960-01-01 to 1960-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1960-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1960-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1960-12-31 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1960-12-31 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1961-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">>", "from 1961-01-02 to 1961-01-03", False),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1958-01-01 to 1959-12-31", False),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1958-01-01 to 1960-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1958-01-01 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1958-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1960-01-01 to 1960-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1960-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1960-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1960-12-31 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1960-12-31 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1961-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", "<=", "from 1961-01-02 to 1961-01-03", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1958-01-01 to 1959-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1958-01-01 to 1960-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1958-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1958-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1960-01-01 to 1960-12-31", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1960-01-01 to 1961-01-01", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1960-01-01 to 1961-01-02", True),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1960-12-31 to 1961-01-01", False),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1960-12-31 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1961-01-01 to 1961-01-02", False),
-        ("from 1960-01-01 to 1961-01-01", ">=", "from 1961-01-02 to 1961-01-03", False),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1958-01-01 to 1959-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1958-01-01 to 1960-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1958-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1958-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1960-01-01 to 1960-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1960-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1960-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1960-12-31 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1960-12-31 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1961-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "=",
+            "from 1961-01-02 to 1961-01-03",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1958-01-01 to 1959-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1958-01-01 to 1960-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1958-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1958-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1960-01-01 to 1960-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1960-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1960-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1960-12-31 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1960-12-31 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1961-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "!=",
+            "from 1961-01-02 to 1961-01-03",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1958-01-01 to 1959-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1958-01-01 to 1960-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1958-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1958-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1960-01-01 to 1960-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1960-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1960-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1960-12-31 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1960-12-31 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1961-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "==",
+            "from 1961-01-02 to 1961-01-03",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1958-01-01 to 1959-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1958-01-01 to 1960-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1958-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1958-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1960-01-01 to 1960-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1960-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1960-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1960-12-31 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1960-12-31 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1961-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<",
+            "from 1961-01-02 to 1961-01-03",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1958-01-01 to 1959-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1958-01-01 to 1960-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1958-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1958-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1960-01-01 to 1960-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1960-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1960-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1960-12-31 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1960-12-31 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1961-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">",
+            "from 1961-01-02 to 1961-01-03",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1958-01-01 to 1959-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1958-01-01 to 1960-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1958-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1958-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1960-01-01 to 1960-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1960-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1960-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1960-12-31 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1960-12-31 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1961-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<<",
+            "from 1961-01-02 to 1961-01-03",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1958-01-01 to 1959-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1958-01-01 to 1960-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1958-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1958-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1960-01-01 to 1960-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1960-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1960-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1960-12-31 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1960-12-31 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1961-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">>",
+            "from 1961-01-02 to 1961-01-03",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1958-01-01 to 1959-12-31",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1958-01-01 to 1960-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1958-01-01 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1958-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1960-01-01 to 1960-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1960-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1960-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1960-12-31 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1960-12-31 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1961-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            "<=",
+            "from 1961-01-02 to 1961-01-03",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1958-01-01 to 1959-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1958-01-01 to 1960-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1958-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1958-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1960-01-01 to 1960-12-31",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1960-01-01 to 1961-01-01",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1960-01-01 to 1961-01-02",
+            True,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1960-12-31 to 1961-01-01",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1960-12-31 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1961-01-01 to 1961-01-02",
+            False,
+        ),
+        (
+            "from 1960-01-01 to 1961-01-01",
+            ">=",
+            "from 1961-01-02 to 1961-01-03",
+            False,
+        ),
     ]
 
     def convert_to_date(self, d):
@@ -1226,7 +1748,10 @@ class EmptyDateTest(BaseDateTest):
 
     def test_range_empty(self):
         d = Date()
-        d.set(value=(1, 1, 1900, False, 1, 1, 1910, False), modifier=Date.MOD_RANGE)
+        d.set(
+            value=(1, 1, 1900, False, 1, 1, 1910, False),
+            modifier=Date.MOD_RANGE,
+        )
         self.assertFalse(d.is_empty())
 
     def test_span_empty(self):
